==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Information/InfoDistancePP/ts/InfoDistancePP_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>InfoDistancePP</name>
    <message>
        <location filename="../InfoDistancePP.js" line="+59"/>
        <source>First point</source>
        <translatorcomment>--google--
Wskaż pierwszy punkt
Wskaż pierwszy punkt wieloboku
Wskaż pierwszy punkt odległości</translatorcomment>
        <translation type="unfinished">Pierwszy punkt</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Second point</source>
        <translatorcomment>--google--
Wskaż drugi punkt
Wskaż dugi punkt odległości
Wskaż drugi punkt linii odbicia</translatorcomment>
        <translation type="unfinished">Drugi punkt</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Done</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Zrobione.
Zrobione
&amp;Zrobione i do następnego</translatorcomment>
        <translation type="unfinished">Zrobione</translation>
    </message>
    <message>
        <location line="+50"/>
        <source>Distance:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Odległość: %1
Zaznacz obiekt do przycięcia lub wprowadź odległość:</translatorcomment>
        <translation type="unfinished">Odległość:</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Delta X:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Delta X:</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Delta Y:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Delta Y:</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Angle:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Wprowadź kąt:
Wskaż położenie linii wymiarowej:</translatorcomment>
        <translation type="unfinished">Kąt:</translation>
    </message>
    <message>
        <location filename="../InfoDistancePPInit.js" line="+2"/>
        <source>Distance &amp;Point to Point</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Punkt Odległość do punktu</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Information/InfoDistancePP/ts/InfoDistancePP_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>InfoDistancePP</name>
    <message>
        <location filename="../InfoDistancePP.js" line="+59"/>
        <source>First point</source>
        <translatorcomment>--google--
Wskaż pierwszy punkt
Wskaż pierwszy punkt wieloboku
Wskaż pierwszy punkt odległości</translatorcomment>
        <translation>Pierwszy punkt</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Second point</source>
        <translatorcomment>--google--
Wskaż drugi punkt
Wskaż dugi punkt odległości
Wskaż drugi punkt linii odbicia</translatorcomment>
        <translation>Drugi punkt</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Done</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Zrobione.
Zrobione
&amp;Zrobione i do następnego</translatorcomment>
        <translation>Zrobione</translation>
    </message>
    <message>
        <location line="+50"/>
        <source>Distance:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Odległość: %1
Zaznacz obiekt do przycięcia lub wprowadź odległość:</translatorcomment>
        <translation>Odległość:</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Delta X:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Delta X:</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Delta Y:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Delta Y:</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Angle:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Wprowadź kąt:
Wskaż położenie linii wymiarowej:</translatorcomment>
        <translation>Kąt:</translation>
    </message>
    <message>
        <location filename="../InfoDistancePPInit.js" line="+2"/>
        <source>Distance &amp;Point to Point</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Odległość p&amp;unktu do punktu</translation>
    </message>
</context>
</TS>
